@@ -20,14 +20,14 @@
 #include <unistd.h>
 
 #include <cstring>  // for strlen
+#include <deque>
 #include <fstream>
 #include <vector>
-#include <deque>
 
 #include "eckit/config/LibEcKit.h"
 #include "eckit/config/Resource.h"
 #include "eckit/filesystem/BasePathNameT.h"
-#include "eckit/filesystem/marsfs/MarsFSPath.h"
+#include "eckit/filesystem/PathNameFactory.h"
 #include "eckit/io/FileHandle.h"
 #include "eckit/io/Length.h"
 #include "eckit/io/PartFileHandle.h"
@@ -39,6 +39,7 @@
 #include "eckit/os/Stat.h"
 #include "eckit/runtime/Main.h"
 #include "eckit/system/Library.h"
+#include "eckit/system/LibraryManager.h"
 #include "eckit/system/SystemInfo.h"
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
@@ -51,15 +52,30 @@ namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-static StaticMutex local_mutex;
+static PathNameBuilder<LocalPathName> localBuilder("local");
+
 static pthread_once_t once = PTHREAD_ONCE_INIT;
 static std::vector<std::pair<std::string, std::string> > pathsTable;
 
+static void expandTilde(std::string& path, bool tildeIsUserHome);
+
 static void readPathsTable() {
 
-    static PathName path = eckit::Resource<PathName>("libraryConfigPaths,$LIBRARY_CONFIG_PATHS", "~/etc/paths");
+    // We would normally just use a PathName object, defaulting to ~/etc/paths. However, this function
+    // is typically called within the constructor of a PathName object, and the recursive call will
+    // hang forever on the std::mutex in the PathName factory.
+    //
+    // expandTilde is internal to LocalPathName anyway, so we call it directly.
 
-    std::ifstream in(path.localPath());
+    static std::string path = eckit::Resource<std::string>("libraryConfigPaths,$LIBRARY_CONFIG_PATHS", "~/etc/paths");
+    static bool expanded    = false;
+
+    if (!expanded) {
+        expandTilde(path, false);
+        expanded = true;
+    }
+
+    std::ifstream in(path);
 
     eckit::Log::debug() << "Loading library paths from " << path << std::endl;
 
@@ -172,7 +188,7 @@ BasePathName* LocalPathName::checkClusterNode() const {
     std::string n = ClusterDisks::node(path_);
     if (n != "local") {
         //        Log::warning() << *this << " is now on node [" << n << "]" << std::endl;
-        return new BasePathNameT<MarsFSPath>(MarsFSPath(n, path_));
+        return PathNameFactory::instance().build(std::string("marsfs://") + n + path_);
     }
     return new BasePathNameT<LocalPathName>(LocalPathName(path_));
 }
@@ -203,13 +219,14 @@ bool LocalPathName::available() const {
 }
 
 LocalPathName LocalPathName::cwd() {
-    AutoLock<StaticMutex> lock(local_mutex);
     char buf[PATH_MAX + 1];
-    if (!getcwd(buf, sizeof(buf)))
+    if (!::getcwd(buf, sizeof(buf)))
         throw FailedSystemCall("getcwd");
     return LocalPathName(buf);
 }
 
+static StaticMutex local_mutex;  // for LocalPathName::unique()
+
 LocalPathName LocalPathName::unique(const LocalPathName& path) {
     AutoLock<StaticMutex> lock(local_mutex);
 
@@ -221,12 +238,15 @@ LocalPathName LocalPathName::unique(const LocalPathName& path) {
     std::ostringstream os;
     os << path << '.' << TimeStamp(format) << '.' << hostname << '.' << n++;
 
-    while (::access(os.str().c_str(), F_OK) == 0) {
+    std::string name = os.str();
+
+    while (::access(name.c_str(), F_OK) == 0) {
         std::ostringstream os;
         os << path << '.' << TimeStamp(format) << '.' << hostname << '.' << n++;
+        name = os.str();
     }
 
-    LocalPathName result(os.str());
+    LocalPathName result(name);
     result.dirName().mkdir();
     return result;
 }
@@ -376,8 +396,8 @@ static void expandTilde(std::string& path, bool tildeIsUserHome) {
 
             // 2. if it has the form ~libname/, then delegate to the matching library to expand the path
 
-            if (eckit::system::Library::exists(s)) {
-                path = eckit::system::Library::lookup(s).expandPath(path);
+            if (eckit::system::LibraryManager::exists(s)) {
+                path = eckit::system::LibraryManager::lookup(s).expandPath(path);
                 return;
             }
 
@@ -405,30 +425,31 @@ static void expandTilde(std::string& path, bool tildeIsUserHome) {
 
 static void tidy_path_tokens(std::vector<std::string>& v) {
 
-    if(v.empty()) return;
+    if (v.empty())
+        return;
 
-    bool absolute = (v[0] == ""); // path started with / -> absolute path
+    bool absolute = (v[0] == "");  // path started with / -> absolute path
 
     std::deque<std::string> path;
     path.push_back(v[0]);
 
-    for(size_t i = 1; i < v.size(); ++i) {
+    for (size_t i = 1; i < v.size(); ++i) {
 
         const std::string& s = v[i];
 
-        if (s.empty() or s == ".") { // when pushing ignore empty entries generated by '//' or '.'
+        if (s.empty() or s == ".") {  // when pushing ignore empty entries generated by '//' or '.'
             continue;
         }
 
         if (s == "..") {
-            if(not path.empty()) {
-                if(path.back() == "..") {
+            if (not path.empty()) {
+                if (path.back() == "..") {
                     path.push_back(s);
                 }
-                else if(path.back() == "") {
+                else if (path.back() == "") {
                     // "/.." -> "/"
                 }
-                else if(path.back() == ".") {
+                else if (path.back() == ".") {
                     path.pop_back();
                     path.push_back(s);
                 }
@@ -437,7 +458,7 @@ static void tidy_path_tokens(std::vector<std::string>& v) {
                 }
             }
             else {
-                if(not absolute) {
+                if (not absolute) {
                     path.push_back(s);
                 }
             }
@@ -449,13 +470,13 @@ static void tidy_path_tokens(std::vector<std::string>& v) {
 
     v.clear();
     v.reserve(path.size());
-    std::copy (path.begin(), path.end(),std::back_inserter(v));
+    std::copy(path.begin(), path.end(), std::back_inserter(v));
 }
 
 static void rebuild_path(const std::vector<std::string>& v, std::string& path, bool trail = false) {
     path.clear();
 
-    if(v.size() == 1 && v[0] == "") { // first entry as empty string is '/'
+    if (v.size() == 1 && v[0] == "") {  // first entry as empty string is '/'
         path = "/";
         return;
     }
@@ -530,7 +551,7 @@ void LocalPathName::match(const LocalPathName& root, std::vector<LocalPathName>&
 
     for (;;) {
         struct dirent* e;
-#ifdef ECKIT_HAVE_READDIR_R
+#ifdef eckit_HAVE_READDIR_R
         errno = 0;
         if (readdir_r(d, &buf, &e) != 0) {
             if (errno)
@@ -625,7 +646,7 @@ void LocalPathName::children(std::vector<LocalPathName>& files, std::vector<Loca
 
     for (;;) {
         struct dirent* e;
-#ifdef ECKIT_HAVE_READDIR_R
+#ifdef eckit_HAVE_READDIR_R
         errno = 0;
         if (readdir_r(d, &buf, &e) != 0) {
             if (errno)
@@ -648,13 +669,15 @@ void LocalPathName::children(std::vector<LocalPathName>& files, std::vector<Loca
 
         bool do_stat = true;
 
-#if defined(ECKIT_HAVE_DIRENT_D_TYPE)
+#if defined(eckit_HAVE_DIRENT_D_TYPE)
         do_stat = false;
         if (e->d_type == DT_DIR) {
-            dirs.push_back(full); 
-        } else if (e->d_type == DT_UNKNOWN) {
+            dirs.push_back(full);
+        }
+        else if (e->d_type == DT_UNKNOWN) {
             do_stat = true;
-        } else {
+        }
+        else {
             files.push_back(full);
         }
 #endif
@@ -738,7 +761,7 @@ bool LocalPathName::isDir() const {
 
 bool LocalPathName::isLink() const {
     Stat::Struct info;
-    if (Stat::stat(path_.c_str(), &info) < 0)
+    if (Stat::lstat(path_.c_str(), &info) < 0)
         throw FailedSystemCall(path_);
     return S_ISLNK(info.st_mode);
 }
@@ -844,7 +867,7 @@ LocalPathName LocalPathName::mountPoint() const {
 
 void LocalPathName::syncParentDirectory() const {
     PathName directory = dirName();
-#ifdef ECKIT_HAVE_DIRFD
+#ifdef eckit_HAVE_DIRFD
     //    Log::info() << "Syncing directory " << directory << std::endl;
     DIR* d = opendir(directory.localPath());
     if (!d)
@@ -854,11 +877,14 @@ void LocalPathName::syncParentDirectory() const {
     SYSCALL(dir = dirfd(d));
     int ret = fsync(dir);
 
-    while (ret < 0 && errno == EINTR)
+    while (ret < 0 && errno == EINTR) {
         ret = fsync(dir);
+    }
 
     if (ret < 0) {
-        Log::error() << "Cannot fsync directory [" << directory << "]" << Log::syserr << std::endl;
+        std::ostringstream oss;
+        Log::error() << "Cannot fsync directory [" << directory << "]";
+        throw FailedSystemCall(oss.str());
     }
 
     ::closedir(d);
