@@ -25,8 +25,8 @@ class Point3;
 
 struct EllipsoidOfRevolution {
     // Convert elliptic coordinates to Cartesian
-    static void convertSphericalToCartesian(const double& radiusA, const double& radiusB,
-                                            const Point2& Alonlat, Point3& B, double height = 0.);
+    static void convertSphericalToCartesian(const double& radiusA, const double& radiusB, const Point2& Alonlat,
+                                            Point3& B, double height = 0.);
 };
 
 //------------------------------------------------------------------------------------------------------
