@@ -12,7 +12,6 @@
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/io/Buffer.h"
-#include "eckit/memory/MemoryPool.h"
 
 namespace eckit {
 
@@ -55,22 +54,24 @@ void Buffer::zero() {
 }
 
 void Buffer::create() {
-    buffer_ = MemoryPool::largeAllocate(size_);
+    buffer_ = static_cast<void*>(new char[size_]);
 }
 
 void Buffer::destroy() {
     if (buffer_) {
-        MemoryPool::largeDeallocate(buffer_);
+        delete[] static_cast<char*>(buffer_);
+        buffer_ = nullptr;
+        size_   = 0;
     }
 }
 
 void Buffer::copy(const std::string& s) {
-    if (s.size()) {
-        ::strcpy(static_cast<char*>(buffer_), s.c_str());
-    }
+    ASSERT(buffer_);
+    ::strncpy(static_cast<char*>(buffer_), s.c_str(), std::min(size_, s.size()));
 }
 
 void Buffer::copy(const char* p, size_t size) {
+    ASSERT(buffer_ && size_ >= size);
     if (size) {
         ::memcpy(buffer_, p, size);
     }
