@@ -20,7 +20,6 @@ class Buffer;
 
 class MemoryHandle : public DataHandle {
 public:
-
     MemoryHandle(const Buffer&);
     MemoryHandle(Buffer&);
 
@@ -30,7 +29,7 @@ public:
 
     MemoryHandle(size_t size = 1024 * 1024, bool grow = true);
 
-    virtual ~MemoryHandle();
+    virtual ~MemoryHandle() override;
 
     /// Access the underlying buffer
     /// Size is provided by both the non-const overriden virtual function size()
@@ -39,50 +38,49 @@ public:
     std::string str() const;
     Length size() const;
 
-// -- Overridden methods
+    // -- Overridden methods
 
     // From DataHandle
 
-    virtual Length openForRead();
-    virtual void openForWrite(const Length&);
-    virtual void openForAppend(const Length&);
+    virtual Length openForRead() override;
+    virtual void openForWrite(const Length&) override;
+    virtual void openForAppend(const Length&) override;
 
-    virtual long read(void*, long);
-    virtual long write(const void*, long);
-    virtual void close();
-    virtual void flush();
-    virtual void rewind();
-    virtual void print(std::ostream&) const;
-    virtual void skip(const Length&);
+    virtual long read(void*, long) override;
+    virtual long write(const void*, long) override;
+    virtual void close() override;
+    virtual void flush() override;
+    virtual void rewind() override;
+    virtual void print(std::ostream&) const override;
+    virtual void skip(const Length&) override;
 
-    virtual Offset seek(const Offset&);
+    virtual Offset seek(const Offset&) override;
 
-    virtual Length size();
-    virtual Length estimate();
-    virtual Offset position();
+    virtual Length size() override;
+    virtual Length estimate() override;
+    virtual Offset position() override;
 
-    virtual DataHandle* clone() const;
+    virtual DataHandle* clone() const override;
 
-private: // members
+private:  // members
+    char* address_;
+    size_t size_;
+    size_t capacity_;
 
-    char*          address_;
-    size_t         size_;
-    size_t         capacity_;
+    bool opened_;
+    bool readOnly_;
+    bool read_;
+    bool grow_;
+    bool owned_;
 
-    bool           opened_;
-    bool           readOnly_;
-    bool           read_;
-    bool           grow_;
-    bool           owned_;
+    Offset position_;
 
-    Offset         position_;
-
-    virtual std::string title() const;
+    virtual std::string title() const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 
 #endif
