@@ -11,7 +11,6 @@
 #include "eckit/eckit.h"
 
 #include "eckit/config/Resource.h"
-#include "eckit/filesystem/marsfs/MarsFSPath.h"
 #include "eckit/io/cluster/NodeInfo.h"
 #include "eckit/log/Bytes.h"
 #include "eckit/log/Log.h"
@@ -66,6 +65,10 @@ void SharedHandle::flush() {
     return handle_.flush();
 }
 
+Length SharedHandle::size() {
+    return handle_.size();
+}
+
 Length SharedHandle::estimate() {
     return handle_.estimate();
 }
@@ -140,8 +143,12 @@ std::string SharedHandle::title() const {
     return handle_.title();
 }
 
-Length SharedHandle::saveInto(DataHandle& other, TransferWatcher& watcher, bool dblBufferOK) {
-    return handle_.saveInto(other, watcher, dblBufferOK);
+void SharedHandle::collectMetrics(const std::string& what) const {
+    handle_.collectMetrics(what);
+}
+
+Length SharedHandle::saveInto(DataHandle& other, TransferWatcher& watcher) {
+    return handle_.saveInto(other, watcher);
 }
 
 //----------------------------------------------------------------------------------------------------------------------
