@@ -14,6 +14,7 @@
 
 #include "eckit/config/Resource.h"
 #include "eckit/filesystem/PathName.h"
+#include "eckit/io/ResizableBuffer.h"
 #include "eckit/log/TimeStamp.h"
 #include "eckit/runtime/Main.h"
 #include "eckit/thread/AutoLock.h"
@@ -23,13 +24,23 @@ namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
+class RotationOutputStream;
+
 static StaticMutex local_mutex;
 
 class RotationOutputStream {
 public:
-    static RotationOutputStream& instance() {
-        static RotationOutputStream theinstance;
-        return theinstance;
+    static RotationOutputStream& instance(const std::string& name) {
+        AutoLock<StaticMutex> lock(local_mutex);
+
+        static std::map<std::string, RotationOutputStream*> instances;
+
+        auto j = instances.find(name);
+        if (j == instances.end()) {
+            instances[name] = new RotationOutputStream(name);
+            j               = instances.find(name);
+        }
+        return *(*j).second;
     }
 
     void write(const char* start, const char* end) {
@@ -44,7 +55,11 @@ public:
     }
 
 private:
-    RotationOutputStream() : logfileFormat_(Resource<std::string>("logfileFormat", "~/log/%Y-%m-%d/out")) {}
+    RotationOutputStream(const std::string& name) :
+        name_(name),
+        logfileFormat_(Resource<std::string>("logfileFormat", "~/log/%Y-%m-%d/out")),
+        buffer_(0),
+        logFilesBufferSize_(Resource<size_t>("logFilesBufferSize", 4 * 1024)) {}
 
     std::ostream& rotout() {
 
@@ -57,12 +72,28 @@ private:
             path.mkdir(0777);
 
             std::ostringstream os;
-            os << path << "/" << Main::instance().name();
+            os << path << "/" << name_;
 
             delete last_;
 
-            /// @todo Find a way to set the close on exec flags
-            last_ = new std::ofstream(os.str().c_str(), std::ios::app);
+            last_ = new std::ofstream();
+
+            if (logFilesBufferSize_) {
+                buffer_.resize(logFilesBufferSize_);
+                buffer_.zero();
+                last_->rdbuf()->pubsetbuf(buffer_, buffer_.size());
+            }
+
+            last_->open(os.str().c_str(), std::ofstream::out | std::ofstream::app);
+            if (last_->fail()) {
+                throw eckit::CantOpenFile(os.str());
+            }
+
+            /// @todo Find a way to set the close on exec flags, 
+            ///       or to get the file descriptor from ofstream so we can do:
+            ///       flags = fcntl(fd, F_GETFD);
+            ///       flags |= FD_CLOEXEC;
+            ///       fcntl(fd, F_SETFD, flags)
 
             lastTime_ = now;
         }
@@ -75,20 +106,27 @@ private:  // members
     std::ofstream* last_ = nullptr;
     time_t lastTime_     = 0;
 
+    std::string name_;
     std::string logfileFormat_;
+    ResizableBuffer buffer_;
+    size_t logFilesBufferSize_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-RotationTarget::RotationTarget() {}
+RotationTarget::RotationTarget(const std::string& name) : name_(name) {
+    if (name_.empty()) {
+        name_ = Main::instance().name();
+    }
+}
 
 RotationTarget::~RotationTarget() {}
 
 void RotationTarget::write(const char* start, const char* end) {
-    RotationOutputStream::instance().write(start, end);
+    RotationOutputStream::instance(name_).write(start, end);
 }
 void RotationTarget::flush() {
-    RotationOutputStream::instance().flush();
+    RotationOutputStream::instance(name_).flush();
 }
 
 void RotationTarget::print(std::ostream& s) const {
