@@ -17,42 +17,37 @@
 #include "eckit/net/NetService.h"
 
 
-//-----------------------------------------------------------------------------
-
 namespace eckit {
+namespace net {
 
-//-----------------------------------------------------------------------------
 
 class Telnet : public NetService {
 public:
+    // -- Contructors
 
-// -- Contructors
+    Telnet(int);
 
-	Telnet(int);
+    // -- Destructor
 
-// -- Destructor
-
-	~Telnet();
+    ~Telnet();
 
 private:
+    // No copy allowed
 
-// No copy allowed
+    Telnet(const Telnet&);
+    Telnet& operator=(const Telnet&);
 
-	Telnet(const Telnet&);
-	Telnet& operator=(const Telnet&);
+    // -- Overridden methods
 
-// -- Overridden methods
-
-	// From NetService
-
-	virtual NetUser* newUser(TCPSocket&);
-	virtual std::string   name() { return "telnet"; }
+    // From NetService
 
+    virtual NetUser* newUser(net::TCPSocket&) const;
+    virtual std::string name() const { return "telnet"; }
 };
 
 
-//-----------------------------------------------------------------------------
+}  // namespace net
+}  // namespace eckit
 
-} // namespace eckit
 
 #endif
