@@ -13,11 +13,9 @@
 #include "eckit/net/Telnet.h"
 
 
-//----------------------------------------------------------------------------------------------------------------------
-
 namespace eckit {
+namespace net {
 
-//----------------------------------------------------------------------------------------------------------------------
 
 Telnetable::Telnetable(int port) : telnet_(new Telnet(port)) {
     if (port != 0)
@@ -28,6 +26,5 @@ Telnetable::~Telnetable() {
     telnet_.stop();
 }
 
-//----------------------------------------------------------------------------------------------------------------------
-
+}  // namespace net
 }  // namespace eckit
