@@ -11,8 +11,8 @@
 #ifndef eckit_os_Stat_h
 #define eckit_os_Stat_h
 
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
 
 #include "eckit/eckit.h"
@@ -22,24 +22,21 @@ namespace eckit {
 //----------------------------------------------------------------------------------------------------------------------
 
 /// struct to manage differences between stat and stat64 different OS's
-struct Stat
-{
+struct Stat {
     /// prefer using stat if supports 64 bit
 
     typedef struct stat Struct;
 
-    static int stat (const char *path, Struct *s){ return ::stat(path,s); }
-    static int lstat(const char *path, Struct *s){ return ::lstat(path,s); }
-    static int fstat(int fd, Struct *s)          { return ::fstat(fd,s); }
+    static int stat(const char* path, Struct* s) { return ::stat(path, s); }
+    static int lstat(const char* path, Struct* s) { return ::lstat(path, s); }
+    static int fstat(int fd, Struct* s) { return ::fstat(fd, s); }
 
 private:
-
-    Stat(); ///< non-instantiable
-
+    Stat();  ///< non-instantiable
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
