@@ -26,6 +26,8 @@
 #include "eckit/log/OStreamTarget.h"
 #include "eckit/log/PrefixTarget.h"
 #include "eckit/os/System.h"
+#include "eckit/system/LibraryManager.h"
+#include "eckit/system/SystemInfo.h"
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
 #include "eckit/utils/Translator.h"
@@ -35,110 +37,9 @@ namespace system {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-/// Registry for all libraries
-///
-class LibraryRegistry {
-
-typedef std::map<std::string, Library*> LibraryMap;
-
-public:  // methods
-
-    /// Builds the registry on demand, needed for correct static initialization
-    /// because factories can be initialized first
-    static LibraryRegistry& instance() {
-        static LibraryRegistry reg;
-        return reg;
-    }
-
-    /// Registers an entry to the registry
-    /// @pre Cannot exist yet
-    /// @param obj pointer must be valid
-    void enregister(const std::string& name, Library* obj) {
-        AutoLock<Mutex> lockme(mutex_);
-        ASSERT(obj);
-        ASSERT(map_.find(name) == map_.end());
-        map_[name] = obj;
-    }
-
-    /// Removes an entry from the registry
-    /// @pre Must exist
-    void deregister(const std::string& name) {
-        AutoLock<Mutex> lockme(mutex_);
-        ASSERT(map_.find(name) != map_.end());
-        map_.erase(name);
-    }
-
-    /// List entries in library
-    std::vector<std::string> list() const {
-        AutoLock<Mutex> lockme(mutex_);
-        std::vector<std::string> result;
-        for (LibraryMap::const_iterator j = map_.begin(); j != map_.end(); ++j) {
-            result.push_back(j->first);
-        }
-        return result;
-    }
-
-    /// Check entry exists in registry
-    bool exists(const std::string& name) const {
-        AutoLock<Mutex> lockme(mutex_);
-        LibraryMap::const_iterator j = map_.find(name);
-        return (j != map_.end());
-    }
-
-    /// Prints the entries in registry
-    void print(std::ostream& out, const char* separator) const {
-        AutoLock<Mutex> lockme(mutex_);
-        std::vector<std::string> l = LibraryRegistry::instance().list();
-        const char* sep               = "";
-        for (auto j : l) {
-            out << sep << j;
-            sep = separator;
-        }
-    }
-
-    /// Lookup entry in the registry
-    Library& lookup(const std::string& name) const {
-        AutoLock<Mutex> lockme(mutex_);
-
-        LibraryMap::const_iterator j = map_.find(name);
-
-        if (j == map_.end()) {
-            eckit::Log::error() << "No Library found with name '" << name << "'" << std::endl;
-            eckit::Log::error() << "Registered libraries are:";
-            print(eckit::Log::error(), "\n");
-            throw eckit::SeriousBug(std::string("No Library found with name ") + name);
-        }
-
-        ASSERT(j->second);
-        return *(j->second);
-    }
-
-private:  // members
-    LibraryMap map_;
-    mutable Mutex mutex_;
-};
-
-//----------------------------------------------------------------------------------------------------------------------
-
-std::vector<std::string> Library::list() {
-    return LibraryRegistry::instance().list();
-}
-
-void Library::list(std::ostream& out) {
-    return LibraryRegistry::instance().print(out, ", ");
-}
-
-bool Library::exists(const std::string& name) {
-    return LibraryRegistry::instance().exists(name);
-}
-
-const Library& Library::lookup(const std::string& name) {
-    return LibraryRegistry::instance().lookup(name);
-}
-
 Library::Library(const std::string& name) : name_(name), prefix_(name), debug_(false) {
 
-    LibraryRegistry::instance().enregister(name, this);
+    LibraryManager::enregister(name, this);
 
     std::transform(prefix_.begin(), prefix_.end(), prefix_.begin(), ::toupper);
 
@@ -295,5 +196,27 @@ void Library::print(std::ostream& out) const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
+std::vector<std::string> Library::list() {
+    return LibraryManager::list();
+}
+
+void Library::list(std::ostream& out) {
+    return LibraryManager::list(out);
+}
+
+bool Library::exists(const std::string& name) {
+    return LibraryManager::exists(name);
+}
+
+const Library& Library::lookup(const std::string& name) {
+    return LibraryManager::lookup(name);
+}
+
+const void * Library::addr() const {
+    return this;
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
 }  // namespace system
 }  // namespace eckit
